@@ -27,7 +27,7 @@ __copyright__ = (
 )
 
 import logging
-from typing import List
+from typing import Dict, List, Optional
 
 import sip
 from qgis.core import (
@@ -39,7 +39,14 @@ from qgis.core import (
 )
 from qgis.gui import QgsMapCanvas
 from qgis.PyQt.QtCore import QObject, pyqtSignal, pyqtSlot
-from qgis.PyQt.QtWidgets import QAction, QDockWidget, QWidget
+from qgis.PyQt.QtWidgets import (
+    QAction,
+    QDockWidget,
+    QMainWindow,
+    QMenuBar,
+    QToolBar,
+    QWidget,
+)
 
 from pytest_qgis.mock_qgis_classes import MockMessageBar
 
@@ -57,7 +64,7 @@ class QgisInterface(QObject):
     currentLayerChanged = pyqtSignal(QgsMapCanvas)  # noqa N802
 
     def __init__(
-        self, canvas: QgsMapCanvas, messageBar: MockMessageBar, mainWindow: QWidget
+        self, canvas: QgsMapCanvas, messageBar: MockMessageBar, mainWindow: QMainWindow
     ) -> None:
         """Constructor
         :param canvas:
@@ -66,6 +73,7 @@ class QgisInterface(QObject):
         self.canvas = canvas
         self._messageBar = messageBar
         self._mainWindow = mainWindow
+        self._active_layer_id: Optional[str] = None
 
         # Set up slots so we can mimic the behaviour of QGIS when layers
         # are added.
@@ -79,6 +87,13 @@ class QgisInterface(QObject):
         self.destCrs = None
         self._layers: List[QgsMapLayer] = []
 
+        # Add the MenuBar
+        menu_bar = QMenuBar()
+        self._mainWindow.setMenuBar(menu_bar)
+
+        # Add the toolbar list
+        self._toolbars: Dict[str, QToolBar] = {}
+
     @pyqtSlot("QList<QgsMapLayer*>")
     def addLayers(self, layers: List[QgsMapLayer]) -> None:
         """Handle layers being added to the registry so they show up in canvas.
@@ -168,12 +183,13 @@ class QgisInterface(QObject):
         """
         pass
 
-    def activeLayer(self) -> QgsMapLayer:
+    def activeLayer(self) -> Optional[QgsMapLayer]:
         """Get pointer to the active layer (layer selected in the legend)."""
-        # noinspection PyArgumentList
-        layers = QgsProject.instance().mapLayers()
-        for item in layers:
-            return layers[item]
+        return (
+            QgsProject.instance().mapLayer(self._active_layer_id)
+            if self._active_layer_id
+            else None
+        )
 
     def addPluginToMenu(self, name: str, action: QAction) -> None:
         """Add plugin item to menu.
@@ -202,13 +218,15 @@ class QgisInterface(QObject):
         """
         pass
 
-    def addToolBar(self, name: str) -> None:
+    def addToolBar(self, name: str) -> QToolBar:
         """Add toolbar with specified name.
 
         :param name: Name for the toolbar.
         :type name: str
         """
-        pass
+        toolbar = QToolBar(name, parent=self._mainWindow)
+        self._toolbars[name] = toolbar
+        return toolbar
 
     def mapCanvas(self) -> QgsMapCanvas:
         """Return a pointer to the map canvas."""
@@ -249,4 +267,4 @@ class QgisInterface(QObject):
         """
         Set the active layer (layer gets selected in the legend)
         """
-        pass
+        self._active_layer_id = layer.id()
